-- Greg Stitt
-- University of Florida

library ieee;
use ieee.std_logic_1164.all;

package sum_pkg is

  -- ideally, we would like to do this, in which case we could specify the
  -- range of the array and the size of each element when a signal is declared.
  -- IMPORTANT: Unfortunately, VHDL (pre 2008) does not support arrays of
  -- unconstrained types.

--  type input_array is array (natural range <>) of std_logic_vector;
  
  -- Therefore, to kind of get around the problem, we still use an array of a
  -- unconstrained type, but we replace the range with a constant that can be
  -- used throughout the code.
  constant SUM_WIDTH : positive := 8;
  type input_array is array (natural range <>) of std_logic_vector(SUM_WIDTH-1 downto 0);

  -- The only problem with this approach is that we are limited to sum entities
  -- with a width of 8. If we wanted one sum entity with a width of 8 and
  -- another sum entity with a width of 4, we would have to use a different
  -- approach. 
  
end sum_pkg;
